@@ -8,15 +8,16 @@ from __future__ import absolute_import
 from __future__ import print_function
 
 import json
-import os
 import logging
-import six
-from copy import deepcopy
+import os
 from collections import OrderedDict
+from copy import deepcopy
 from datetime import datetime
 
-from pybufrkit.errors import PyBufrKitError
+import six
+
 from pybufrkit.constants import BASE_DIR, NBITS_PER_BYTE, PARAMETER_TYPE_TEMPLATE_DATA
+from pybufrkit.errors import PyBufrKitError
 from pybufrkit.tables import TableGroupCacheManager
 
 log = logging.getLogger(__file__)
@@ -27,7 +28,7 @@ class SectionParameter(object):
     This class represents a Parameter of a Bufr Section.
     """
 
-    def __init__(self, name, nbits, data_type, expected, as_property, value=None):
+    def __init__(self, name, nbits, data_type, expected, as_property, optional=False, value=None):
         # type: (str, int, str, object, bool) -> None
         self.name = name
         self.nbits = nbits
@@ -38,9 +39,13 @@ class SectionParameter(object):
             expected = expected.encode('utf-8')
         self.expected = expected
         self.as_property = as_property
+        self.optional = optional
         self.parent = None  # the section that parameter belongs to
         self.value = value
 
+    def __str__(self):
+        return 'name={}, type={}, nbits={}, value={}'.format(self.name, self.type, self.nbits, self.value)
+
 
 class SectionNamespace(OrderedDict):
     """
@@ -126,6 +131,9 @@ class BufrSection(object):
         else:
             raise PyBufrKitError('Parameter "{}" not found'.format(parameter_name))
 
+    def has_optional_last_parameter(self):
+        return list(self._namespace.values())[-1].optional
+
 
 # An indicator for using the fallback default edition of a section
 DEFAULT_SECTION_EDITION = 0
@@ -183,26 +191,36 @@ class SectionConfigurer(object):
         section.set_metadata('optional', config.get('optional', False))
         section.set_metadata('end_of_message', config.get('end_of_message', False))
 
-        for parameter in config['parameters']:
+        for idx, parameter in enumerate(config['parameters']):
             data_type = parameter['type']
             nbits = parameter['nbits']
+            optional = parameter.get('optional', False)
             if data_type == 'bytes':
                 assert nbits % NBITS_PER_BYTE == 0, \
                     'nbits for bytes type must be integer multiple of 8: {}'.format(nbits)
+            if nbits == 0 or optional:
+                assert nbits == 0, 'section {} optional parameter {} must have 0 bits, but got {}'.format(
+                    section_index, parameter['name'], nbits)
+                assert data_type in ('bin', 'bytes', 'unexpanded_descriptors', 'template_data'), \
+                    'section {} parameter {} with nbits 0 has incorrect data type {}'.format(
+                        section_index, parameter['name'], data_type)
+                assert idx == len(config['parameters']) - 1, \
+                    'section {} parameter {} with nbits 0 must be at the end'.format(section_index, parameter['name'])
             section_parameter = SectionParameter(
                 parameter['name'],
                 nbits,
                 data_type,
                 parameter.get('expected', None),
-                parameter.get('as_property', False)
+                parameter.get('as_property', False),
+                optional
             )
             section.add_parameter(section_parameter)
 
         # Check whether this section is optional. If it is optional, check whether it exists in the
         # current message.
         is_section_presents = (
-            not section.optional or
-            getattr(bufr_message, 'is_section{}_presents'.format(section_index)).value
+                not section.optional or
+                getattr(bufr_message, 'is_section{}_presents'.format(section_index)).value
         )
 
         # If the section exists, add the section for process other wise ignore it
@@ -242,11 +260,16 @@ class SectionConfigurer(object):
         """
         section = self.configure_section(bufr_message, section_index)
         if section is not None:
-            assert len(section) == len(values), \
-                'Number of Section parameters ({}) not equal to number of values to be encoded ({})'.format(
-                    len(section), len(values))
-            for idx, parameter in enumerate(section):
-                parameter.value = values[idx] if overrides is None else overrides.get(parameter.name, values[idx])
+            if section.has_optional_last_parameter():
+                assert len(section) == len(values) or len(section) == len(values) + 1, \
+                    'Inconsistent number of section parameters {} and number of values {}'.format(len(section),
+                                                                                                  len(values))
+            else:
+                assert len(section) == len(values), \
+                    'Number of Section parameters ({}) not equal to number of values to be encoded ({})'.format(
+                        len(section), len(values))
+            for idx, (parameter, value) in enumerate(zip(section, values)):
+                parameter.value = value if overrides is None else overrides.get(parameter.name, value)
 
         return section
 
