@@ -15,10 +15,11 @@ except ImportError:  # py2
 __all__ = ['prepare_wmo_tables']
 
 
-def prepare_wmo_tables(version, tag):
+def prepare_wmo_tables(version, tag=None, output_dir='.'):
+    tag = tag or version
     data = download_wmo_bufr_tables_release(version, tag)
     tables = convert_tables_from_zip(version, data)
-    write_tables(version, tables, '.')
+    write_tables(version, tables, output_dir)
 
 
 def download_wmo_bufr_tables_release(version, tag):
@@ -39,7 +40,7 @@ def convert_tables_from_zip(version, data):
     table_code_and_flag = {}
     for fileinfo in zf.infolist():
         if fileinfo.filename.startswith('BUFR4-{}{}BUFRCREX_TableB_en_'.format(version, os.path.sep)):
-            print('Table B: ' + fileinfo.filename)
+            # print('Table B: ' + fileinfo.filename)
             table_b.update(process_table_b(zf.read(fileinfo).decode('utf-8')))
         elif fileinfo.filename.startswith('BUFR4-{}{}BUFR_TableD_en_'.format(version, os.path.sep)):
             table_d.update(process_table_d(zf.read(fileinfo).decode('utf-8')))
@@ -57,7 +58,7 @@ def convert_tables_from_zip(version, data):
 def write_tables(version, tables, output_dir):
     base_dir = os.path.join(output_dir, '{}'.format(version))
     print('Saving tables inside folder: {}'.format(base_dir))
-    os.makedirs(base_dir)
+    os.makedirs(base_dir, exist_ok=True)
     with open(os.path.join(base_dir, 'TableB.json'), 'w') as outs:
         json.dump(tables['b'], outs, sort_keys=True)
     with open(os.path.join(base_dir, 'TableD.json'), 'w') as outs:
@@ -76,7 +77,8 @@ def process_table_b(content):
     for line in lines:
         crex_scale = 0 if line[9 + offset] == '' else int(line[9 + offset])
         crex_data_width = 0 if line[10 + offset] == '' else int(line[10 + offset])
-        d[line[2]] = [line[3], line[4 + offset], int(line[5 + offset]), int(line[6 + offset]), int(line[7 + offset]), line[8 + offset], crex_scale, crex_data_width]
+        d[line[2]] = [line[3], line[4 + offset], int(line[5 + offset]), int(line[6 + offset]), int(line[7 + offset]),
+                      line[8 + offset], crex_scale, crex_data_width]
     return d
 
 
