@@ -414,21 +414,21 @@ class DataQueryTests(unittest.TestCase):
         r5 = self.querent.query(bufr_message, '008002')
         assert r5.all_values(flat=True) == [
             [5, 5, 11, 7, 8, 9, None],
-            [7, 1, 12, 7, 8, 9, None],
-            [7, 1, 12, 7, 8, 9, None],
-            [7, 1, 12, 7, 8, 9, None],
-            [7, 1, 12, 7, 8, 9, None],
-            [7, 1, 12, 7, 8, 9, None],
-            [0, 1, 12, 7, 8, 9, None],
+            [7, 1, None, 7, 8, 9, None],
+            [7, 1, None, 7, 8, 9, None],
+            [7, 1, None, 7, 8, 9, None],
+            [7, 1, None, 7, 8, 9, None],
+            [7, 1, None, 7, 8, 9, None],
+            [0, 1, None, 7, 8, 9, None],
         ]
         assert r5.all_values() == [
             [5, [[5]], [[11]], [[7], [8], [9]], None],
-            [7, [[1]], [[12]], [[7], [8], [9]], None],
-            [7, [[1]], [[12]], [[7], [8], [9]], None],
-            [7, [[1]], [[12]], [[7], [8], [9]], None],
-            [7, [[1]], [[12]], [[7], [8], [9]], None],
-            [7, [[1]], [[12]], [[7], [8], [9]], None],
-            [0, [[1]], [[12]], [[7], [8], [9]], None],
+            [7, [[1]], [[None]], [[7], [8], [9]], None],
+            [7, [[1]], [[None]], [[7], [8], [9]], None],
+            [7, [[1]], [[None]], [[7], [8], [9]], None],
+            [7, [[1]], [[None]], [[7], [8], [9]], None],
+            [7, [[1]], [[None]], [[7], [8], [9]], None],
+            [0, [[1]], [[None]], [[7], [8], [9]], None],
         ]
 
         r6 = self.querent.query(bufr_message, '@[4] > 302047 > 008002')
@@ -553,3 +553,13 @@ class DataQueryTests(unittest.TestCase):
                 [[[[12], [10], [8]]], [[[6], [4]]]]
             ]
         ]
+
+    def test_iterate_query_result(self):
+        s = read_bufr_file('jaso_214.bufr')
+        bufr_message = self.decoder.process(s)
+
+        r1 = self.querent.query(bufr_message, '/301011/004001')
+        it = iter(r1)
+        next(it)
+        next(it)
+        next(it)
\ No newline at end of file
